Crate normalize_output

Crate normalize_output 

Output formatting utilities.

Provides text formatting via the OutputFormatter trait. JSON/jq/jsonl/schema output is handled by server-less at the CLI macro level.

Modules

diagnostics
Unified diagnostic types for all issue-reporting commands.

Structs

PrettyConfig
Configuration for pretty output mode.

Enums

ColorMode
Color output mode.

Traits

OutputFormatter
Trait for types that can format output in multiple formats.

Functions

progress_bar
Render a plain (uncolored) progress bar using block characters.
progress_bar_bad
Render a colored progress bar where high ratio = bad (red) and low = good (green).
progress_bar_good
Render a colored progress bar where high ratio = good (green) and low = bad (red).