pub struct RelatedLocation {
pub file: String,
pub line: Option<usize>,
pub message: Option<String>,
}Expand description
A secondary location related to an issue (e.g., the other file in a circular dep).
Fields
file: Stringline: Option<usize>message: Option<String>Trait Implementations
Sourceimpl Archive for RelatedLocation
impl Archive for RelatedLocation
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedRelatedLocation
type Archived = ArchivedRelatedLocation
The archived representation of this type. Read more
Sourcetype Resolver = RelatedLocationResolver
type Resolver = RelatedLocationResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for RelatedLocation
impl Clone for RelatedLocation
Sourcefn clone(&self) -> RelatedLocation
fn clone(&self) -> RelatedLocation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RelatedLocation
impl Debug for RelatedLocation
Sourceimpl<'de> Deserialize<'de> for RelatedLocation
impl<'de> Deserialize<'de> for RelatedLocation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<RelatedLocation, __D> for Archived<RelatedLocation>
impl<__D: Fallible + ?Sized> Deserialize<RelatedLocation, __D> for Archived<RelatedLocation>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<RelatedLocation, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<RelatedLocation, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl JsonSchema for RelatedLocation
impl JsonSchema for RelatedLocation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RelatedLocation
impl RefUnwindSafe for RelatedLocation
impl Send for RelatedLocation
impl Sync for RelatedLocation
impl Unpin for RelatedLocation
impl UnsafeUnpin for RelatedLocation
impl UnwindSafe for RelatedLocation